Exception: Solace::Errors::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/solace/errors/error.rb

Overview

Base error class for all Solace errors.

All Solace-specific exceptions inherit from this class, allowing consumers to rescue all Solace errors with a single clause:

Examples:

Rescuing all Solace errors

begin
  connection.(address)
rescue Solace::Errors::Error => e
  puts "Solace error: #{e.message}"
end

Since:

  • 0.1.4

Direct Known Subclasses

ConfirmationTimeout, ConnectionError, ParseError