Module: Solace::Instructions::AssociatedTokenAccount

Defined in:
lib/solace/instructions/associated_token_account/create_account_instruction.rb,
lib/solace/instructions/associated_token_account/create_idempotent_account_instruction.rb

Overview

The AssociatedTokenAccount module contains instruction builders for the Associated Token Account Program.

The Associated Token Account (ATA) Program provides a deterministic way to derive token account addresses for a given wallet and mint. This ensures that each wallet has a single, predictable token account for each token type.

Defined Under Namespace

Classes: CreateAccountInstruction, CreateIdempotentAccountInstruction

Constant Summary collapse

CreateAssociatedTokenAccountInstruction =

Alias for CreateAccountInstruction for backward compatibility

Since:

  • 0.0.2

CreateAccountInstruction