Class: Solace::Instructions::AssociatedTokenAccount::CreateIdempotentAccountInstruction
- Inherits:
-
CreateAccountInstruction
- Object
- CreateAccountInstruction
- Solace::Instructions::AssociatedTokenAccount::CreateIdempotentAccountInstruction
- Defined in:
- lib/solace/instructions/associated_token_account/create_idempotent_account_instruction.rb
Overview
Instruction for creating an Associated Token Account idempotently.
This instruction behaves like CreateAccountInstruction, but will not fail
if the account already exists. This is useful for scenarios where the existence of the
account is uncertain, and you want to ensure it exists without causing an error.
Constant Summary collapse
- INSTRUCTION_INDEX =
!@const INSTRUCTION_INDEX Instruction index for CreateIdempotentAccount
[1].freeze
Class Method Summary collapse
-
.data ⇒ Array
Data for a CreateAccount instruction.
Methods inherited from CreateAccountInstruction
Class Method Details
.data ⇒ Array
Data for a CreateAccount instruction
The BufferLayout is:
- [Instruction Index (1 byte)]
46 47 48 |
# File 'lib/solace/instructions/associated_token_account/create_idempotent_account_instruction.rb', line 46 def self.data INSTRUCTION_INDEX end |