Module: Solace::Instructions::SystemProgram

Defined in:
lib/solace/instructions/system_program/transfer_instruction.rb,
lib/solace/instructions/system_program/create_account_instruction.rb

Overview

The SystemProgram module contains instruction builders for the System Program.

The System Program is Solana’s native program for fundamental operations like creating accounts, transferring SOL, and allocating account data. It is the only program that can create new accounts and assign them to other programs.

This module contains classes that build the low-level instruction data required to interact with the System Program.

Defined Under Namespace

Classes: CreateAccountInstruction, TransferInstruction