Exception: Solace::Errors::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Solace::Errors::Error
- Defined in:
- lib/solace/errors/error.rb
Overview
Base error class for all Solace errors.
All Solace-specific exceptions inherit from this class, allowing consumers to rescue all Solace errors with a single clause: